# yiwen song

[![Build Status](https://travis-ci.org/yiwensong/resume.svg?branch=main)](https://travis-ci.org/yiwensong/resume)
[![Coverage Status](https://coveralls.io/repos/github/yiwensong/resume/badge.svg?branch=main)](https://coveralls.io/github/yiwensong/resume?branch=main)
[![PyPI version](https://badge.fury.io/py/md-resume.svg)](https://badge.fury.io/py/md-resume)

[Personal Site](http://yiwensong.com) |
[Email](mailto:songzgy@gmail.com)

---
## Work Experience
### Sync at Airtable (Feb 2022 - present)
*New York City, NY*

* Designed and led several improvements to the sync product's observability, including an internal tool to track run history and a cross-server tracing scheme for a cross-service system on top of traditionally monolithic tooling.
* Contributed to the Real-Time Sync project, which was a multi-team and multi-quarter initiative to add a live-editing experience between multiple Airtable bases.
* Following this launch, led efforts to significantly improve performance and scaling: reduced end-to-end latency P99 from 24s to 4s and increased the per-base sync limit from 100 to 2000.

### Deploy at Stripe (Apr 2019 - Aug 2021)
*San Francisco, CA (and partially remote)*

* Led project for building out automated deployment health evaluation. Deployments went from fully manually evaluated to 80%+ automatic evaluation.
* Designed and implemented blue/green deployments on top of Stripe's Kubernetes platform to improve services' reliability and fault tolerance story.
* Contributed to the accessibility and usability designs of internal developer tooling webface by adding and migrating to page templates and standardized components.
* Holds the (unofficial) team record for most robot tickets cleared in a week (a major contributor to the team's debt and toil).

### Release Engineering at Yelp (Nov 2017 - Apr 2019)
*San Francisco, CA*

* Designed and implemented API for determining responsibility and ownership of code, databases, and other resources.
* Worked on an internal frontend service that tracks and displays tech debt and developer productivity.
* Improved Git management tools and code review infrastructure to be more resilient to catastrophic failures.

### Trading and Data at Old Mission Capital (Aug 2016 - May 2017)
*Chicago, IL*

* Improved data pipeline and research infrastructure reliability and usability.
* Added parallelism to data ingestion and created automated gut-check test suites to reduce overhead of analysis.
* Developed a Python package for quickly scripting models and risk calculation on live market data.

### Trading Intern at Old Mission Capital (Jun 2015 - Aug 2015)

---
## Education
### University of California, Berkeley - June 2016

Computer Science, B.A.  
Major GPA: 3.739  

---
## SEO
**Interests**: Scale and reliability, developer productivity tooling, making frontend changes but only as a hobby  
**Languages**: Python, Typescript/Javascript/React, Golang, Psuedocode, fish, Mandarin  
**Skills**: INDEX-MATCH fiend, vim config fiddler, top 5% in valorant and tft, "sudo rm -rf /" frequent user  
**Intangibles**: Clicks buttons really fast, reads the manual  
**Literally just SEO terms that vaguely relate to my work**:
Cloud computing, devops, dev-ops, design, software engineering,
software developer, infrastructure, SRE, reliability engineering, docker,
containers, kuberenetes, AWS, amazon web services, s3, EC2,
google cloud platform, gcp, puppet, terraform, services, continous deployment,
continuous integration, CI, CD, CI/CD, Jenkins, build, test execution,
test infrastructure, developer tooling, tox, make, bazel, UI, UX,
web developer, web development, web dev, SaaS, PaaS, backend,
development to production, DNS, load balancer, Travis, Chef, postgres, mysql,
mongodb, database management, migrations, AI, ML,
I don't actually know AI or ML but maybe I get more clicks this way  
